@@ -63,9 +63,6 @@ term_signal_caught = False
 
 univention.admin.modules.update()
 
-# update choices-lists which are defined in LDAP
-univention.admin.syntax.update_choices()
-
 try:
 	univention.admin.handlers.disable_ad_restrictions(disable=False)
 except AttributeError:
@@ -192,10 +189,16 @@ class configdb(object):
 				self._dbcon = lite.connect(self.filename)
 
 	def set(self, section, option, value):
+		cmd = "INSERT OR REPLACE INTO '%s' (key, value) VALUES (?, ?);" % (section,)
+		val = [option, value]
+		if section == "AD rejected":
+			# update retry_count
+			cmd = "INSERT OR REPLACE INTO '%s' (key, value, retry_count) VALUES (?, ?, COALESCE((SELECT retry_count FROM '%s' WHERE key = ? )+1 ,0));" % (section, section)
+			val = [option, value, option]
 		for i in [1, 2]:
 			try:
 				cur = self._dbcon.cursor()
-				cur.execute("INSERT OR REPLACE INTO '%s' (key, value) VALUES (?, ?);" % section, [option, value])
+				cur.execute(cmd, val)
 				self._dbcon.commit()
 				cur.close()
 				return
@@ -254,7 +257,10 @@ class configdb(object):
 		for i in [1, 2]:
 			try:
 				cur = self._dbcon.cursor()
-				cur.execute("CREATE TABLE IF NOT EXISTS '%s' (Key TEXT PRIMARY KEY, Value TEXT)" % section)
+				if section in ["AD rejected"]:
+					cur.execute("CREATE TABLE IF NOT EXISTS '%s' (Key TEXT PRIMARY KEY, Value TEXT, retry_count NUMBER DEFAULT 0)" % section)
+				else:
+					cur.execute("CREATE TABLE IF NOT EXISTS '%s' (Key TEXT PRIMARY KEY, Value TEXT)" % section)
 				self._dbcon.commit()
 				cur.close()
 				return
